/****************************************************************************
** Meta object code from reading C++ file 'radicalbutton.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiten-17.04.3/radselect/radicalbutton.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'radicalbutton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_RadicalButton_t {
    QByteArrayData data[13];
    char stringdata0[148];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RadicalButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RadicalButton_t qt_meta_stringdata_RadicalButton = {
    {
QT_MOC_LITERAL(0, 0, 13), // "RadicalButton"
QT_MOC_LITERAL(1, 14, 11), // "userClicked"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 4), // "text"
QT_MOC_LITERAL(4, 32, 27), // "RadicalButton::ButtonStatus"
QT_MOC_LITERAL(5, 60, 6), // "status"
QT_MOC_LITERAL(6, 67, 15), // "mousePressEvent"
QT_MOC_LITERAL(7, 83, 12), // "QMouseEvent*"
QT_MOC_LITERAL(8, 96, 1), // "e"
QT_MOC_LITERAL(9, 98, 17), // "mouseReleaseEvent"
QT_MOC_LITERAL(10, 116, 11), // "resetButton"
QT_MOC_LITERAL(11, 128, 9), // "setStatus"
QT_MOC_LITERAL(12, 138, 9) // "newStatus"

    },
    "RadicalButton\0userClicked\0\0text\0"
    "RadicalButton::ButtonStatus\0status\0"
    "mousePressEvent\0QMouseEvent*\0e\0"
    "mouseReleaseEvent\0resetButton\0setStatus\0"
    "newStatus"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RadicalButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   44,    2, 0x0a /* Public */,
       9,    1,   47,    2, 0x0a /* Public */,
      10,    0,   50,    2, 0x0a /* Public */,
      11,    1,   51,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4,    3,    5,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,   12,

       0        // eod
};

void RadicalButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RadicalButton *_t = static_cast<RadicalButton *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->userClicked((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< RadicalButton::ButtonStatus(*)>(_a[2]))); break;
        case 1: _t->mousePressEvent((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 2: _t->mouseReleaseEvent((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 3: _t->resetButton(); break;
        case 4: _t->setStatus((*reinterpret_cast< RadicalButton::ButtonStatus(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (RadicalButton::*_t)(const QString & , RadicalButton::ButtonStatus );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RadicalButton::userClicked)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject RadicalButton::staticMetaObject = {
    { &QPushButton::staticMetaObject, qt_meta_stringdata_RadicalButton.data,
      qt_meta_data_RadicalButton,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *RadicalButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RadicalButton::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_RadicalButton.stringdata0))
        return static_cast<void*>(const_cast< RadicalButton*>(this));
    return QPushButton::qt_metacast(_clname);
}

int RadicalButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPushButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void RadicalButton::userClicked(const QString & _t1, RadicalButton::ButtonStatus _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
