/****************************************************************************
** Meta object code from reading C++ file 'resultsview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiten-17.04.3/app/resultsview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resultsview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_ResultsView_t {
    QByteArrayData data[15];
    char stringdata0[128];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ResultsView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ResultsView_t qt_meta_stringdata_ResultsView = {
    {
QT_MOC_LITERAL(0, 0, 11), // "ResultsView"
QT_MOC_LITERAL(1, 12, 23), // "entrySpecifiedForExport"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 5), // "index"
QT_MOC_LITERAL(4, 43, 10), // "urlClicked"
QT_MOC_LITERAL(5, 54, 6), // "append"
QT_MOC_LITERAL(6, 61, 4), // "text"
QT_MOC_LITERAL(7, 66, 5), // "clear"
QT_MOC_LITERAL(8, 72, 5), // "flush"
QT_MOC_LITERAL(9, 78, 5), // "print"
QT_MOC_LITERAL(10, 84, 5), // "title"
QT_MOC_LITERAL(11, 90, 12), // "setBasicMode"
QT_MOC_LITERAL(12, 103, 3), // "yes"
QT_MOC_LITERAL(13, 107, 11), // "setContents"
QT_MOC_LITERAL(14, 119, 8) // "doScroll"

    },
    "ResultsView\0entrySpecifiedForExport\0"
    "\0index\0urlClicked\0append\0text\0clear\0"
    "flush\0print\0title\0setBasicMode\0yes\0"
    "setContents\0doScroll"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ResultsView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       4,    1,   62,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   65,    2, 0x0a /* Public */,
       7,    0,   68,    2, 0x0a /* Public */,
       8,    0,   69,    2, 0x0a /* Public */,
       9,    1,   70,    2, 0x0a /* Public */,
      11,    1,   73,    2, 0x0a /* Public */,
      13,    1,   76,    2, 0x0a /* Public */,
      14,    0,   79,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::QString,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void,

       0        // eod
};

void ResultsView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ResultsView *_t = static_cast<ResultsView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->entrySpecifiedForExport((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->urlClicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->append((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->clear(); break;
        case 4: _t->flush(); break;
        case 5: _t->print((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->setBasicMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->setContents((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->doScroll(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ResultsView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ResultsView::entrySpecifiedForExport)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ResultsView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ResultsView::urlClicked)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject ResultsView::staticMetaObject = {
    { &KHTMLPart::staticMetaObject, qt_meta_stringdata_ResultsView.data,
      qt_meta_data_ResultsView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *ResultsView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResultsView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_ResultsView.stringdata0))
        return static_cast<void*>(const_cast< ResultsView*>(this));
    return KHTMLPart::qt_metacast(_clname);
}

int ResultsView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KHTMLPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ResultsView::entrySpecifiedForExport(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ResultsView::urlClicked(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_END_MOC_NAMESPACE
