/****************************************************************************
** Meta object code from reading C++ file 'configuredialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiten-17.04.3/app/configuredialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'configuredialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_ConfigureDialog_t {
    QByteArrayData data[10];
    char stringdata0[177];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ConfigureDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ConfigureDialog_t qt_meta_stringdata_ConfigureDialog = {
    {
QT_MOC_LITERAL(0, 0, 15), // "ConfigureDialog"
QT_MOC_LITERAL(1, 16, 21), // "settingsChangedSignal"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 19), // "updateWidgetsSignal"
QT_MOC_LITERAL(4, 59, 26), // "updateWidgetsDefaultSignal"
QT_MOC_LITERAL(5, 86, 20), // "updateSettingsSignal"
QT_MOC_LITERAL(6, 107, 19), // "updateConfiguration"
QT_MOC_LITERAL(7, 127, 14), // "updateSettings"
QT_MOC_LITERAL(8, 142, 13), // "updateWidgets"
QT_MOC_LITERAL(9, 156, 20) // "updateWidgetsDefault"

    },
    "ConfigureDialog\0settingsChangedSignal\0"
    "\0updateWidgetsSignal\0updateWidgetsDefaultSignal\0"
    "updateSettingsSignal\0updateConfiguration\0"
    "updateSettings\0updateWidgets\0"
    "updateWidgetsDefault"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ConfigureDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x06 /* Public */,
       3,    0,   55,    2, 0x06 /* Public */,
       4,    0,   56,    2, 0x06 /* Public */,
       5,    0,   57,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   58,    2, 0x08 /* Private */,
       7,    0,   59,    2, 0x08 /* Private */,
       8,    0,   60,    2, 0x08 /* Private */,
       9,    0,   61,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ConfigureDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ConfigureDialog *_t = static_cast<ConfigureDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->settingsChangedSignal(); break;
        case 1: _t->updateWidgetsSignal(); break;
        case 2: _t->updateWidgetsDefaultSignal(); break;
        case 3: _t->updateSettingsSignal(); break;
        case 4: _t->updateConfiguration(); break;
        case 5: _t->updateSettings(); break;
        case 6: _t->updateWidgets(); break;
        case 7: _t->updateWidgetsDefault(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ConfigureDialog::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ConfigureDialog::settingsChangedSignal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ConfigureDialog::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ConfigureDialog::updateWidgetsSignal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ConfigureDialog::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ConfigureDialog::updateWidgetsDefaultSignal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ConfigureDialog::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ConfigureDialog::updateSettingsSignal)) {
                *result = 3;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject ConfigureDialog::staticMetaObject = {
    { &KConfigDialog::staticMetaObject, qt_meta_stringdata_ConfigureDialog.data,
      qt_meta_data_ConfigureDialog,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *ConfigureDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConfigureDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_ConfigureDialog.stringdata0))
        return static_cast<void*>(const_cast< ConfigureDialog*>(this));
    return KConfigDialog::qt_metacast(_clname);
}

int ConfigureDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void ConfigureDialog::settingsChangedSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void ConfigureDialog::updateWidgetsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void ConfigureDialog::updateWidgetsDefaultSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, Q_NULLPTR);
}

// SIGNAL 3
void ConfigureDialog::updateSettingsSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
