/****************************************************************************
** Meta object code from reading C++ file 'kanjibrowserview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiten-17.04.3/kanjibrowser/kanjibrowserview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kanjibrowserview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_KanjiBrowserView_t {
    QByteArrayData data[14];
    char stringdata0[165];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KanjiBrowserView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KanjiBrowserView_t qt_meta_stringdata_KanjiBrowserView = {
    {
QT_MOC_LITERAL(0, 0, 16), // "KanjiBrowserView"
QT_MOC_LITERAL(1, 17, 16), // "statusBarChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 4), // "text"
QT_MOC_LITERAL(4, 40, 12), // "loadSettings"
QT_MOC_LITERAL(5, 53, 11), // "changeGrade"
QT_MOC_LITERAL(6, 65, 5), // "grade"
QT_MOC_LITERAL(7, 71, 16), // "changeToInfoPage"
QT_MOC_LITERAL(8, 88, 16), // "changeToListPage"
QT_MOC_LITERAL(9, 105, 17), // "changeStrokeCount"
QT_MOC_LITERAL(10, 123, 7), // "strokes"
QT_MOC_LITERAL(11, 131, 11), // "searchKanji"
QT_MOC_LITERAL(12, 143, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(13, 160, 4) // "item"

    },
    "KanjiBrowserView\0statusBarChanged\0\0"
    "text\0loadSettings\0changeGrade\0grade\0"
    "changeToInfoPage\0changeToListPage\0"
    "changeStrokeCount\0strokes\0searchKanji\0"
    "QListWidgetItem*\0item"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KanjiBrowserView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   52,    2, 0x0a /* Public */,
       5,    1,   53,    2, 0x08 /* Private */,
       7,    0,   56,    2, 0x08 /* Private */,
       8,    0,   57,    2, 0x08 /* Private */,
       9,    1,   58,    2, 0x08 /* Private */,
      11,    1,   61,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, 0x80000000 | 12,   13,

       0        // eod
};

void KanjiBrowserView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KanjiBrowserView *_t = static_cast<KanjiBrowserView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->statusBarChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->loadSettings(); break;
        case 2: _t->changeGrade((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 3: _t->changeToInfoPage(); break;
        case 4: _t->changeToListPage(); break;
        case 5: _t->changeStrokeCount((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 6: _t->searchKanji((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KanjiBrowserView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KanjiBrowserView::statusBarChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KanjiBrowserView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KanjiBrowserView.data,
      qt_meta_data_KanjiBrowserView,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *KanjiBrowserView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KanjiBrowserView::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_KanjiBrowserView.stringdata0))
        return static_cast<void*>(const_cast< KanjiBrowserView*>(this));
    return QWidget::qt_metacast(_clname);
}

int KanjiBrowserView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KanjiBrowserView::statusBarChanged(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
